==> haskell-wl-pprint-annotated-0.1.0.1-335-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-annotated
version:              0.1.0.1
visibility:           public
id:                   wl-pprint-annotated-0.1.0.1-H9E4YZYyucVC027bBnIIK9
key:                  wl-pprint-annotated-0.1.0.1-H9E4YZYyucVC027bBnIIK9
license:              BSD-3-Clause
copyright:            2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
stability:            experimental
homepage:             https://github.com/minad/wl-pprint-annotated#readme
synopsis:             Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.

category:             Text
abi:                  b9661be29f80f387d9abbe8a869e0eaa
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.WL
hidden-modules:       Paths_wl_pprint_annotated
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-annotated
hs-libraries:         HSwl-pprint-annotated-0.1.0.1-H9E4YZYyucVC027bBnIIK9
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-annotated-0.1.0.1-337-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-annotated
version:              0.1.0.1
visibility:           public
id:                   wl-pprint-annotated-0.1.0.1-J4oWbOZaHnHLrZn8uPrSA4
key:                  wl-pprint-annotated-0.1.0.1-J4oWbOZaHnHLrZn8uPrSA4
license:              BSD-3-Clause
copyright:            2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
stability:            experimental
homepage:             https://github.com/minad/wl-pprint-annotated#readme
synopsis:             Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.

category:             Text
abi:                  ba0933a0b01877981c04249dba182f2f
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.WL
hidden-modules:       Paths_wl_pprint_annotated
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-annotated
hs-libraries:         HSwl-pprint-annotated-0.1.0.1-J4oWbOZaHnHLrZn8uPrSA4
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
